==> react-named-router-0.1.0.tgz: package/es6/utils.js <==
const buildRawPath = (map, name) => {
    const route = map.get(name);
    if (!route) {
        throw new Error(`Undefined route "${name}"`);
    }
    if (!route.path) {
        throw new Error(`Route "${name}" does not have a path`);
    }
    return route.path;
};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const buildRoutePath = (map, name, params = {}) => (buildRawPath(map, name)
    .replace(/:\w+\??/g, (match) => {
    const paramKey = match.replace(/[:?]/g, '');
    const paramValue = params[paramKey];
    if (!paramValue && !match.includes('?')) {
        throw new Error(`Missing value for required param "${paramKey}"`);
    }
    return paramValue || '';
})
    .replace(/\/$/, ''));
export const mapRoutes = (routes, parents = [], map = new Map()) => {
    routes.forEach((route) => {
        if (route.routes) {
            mapRoutes(route.routes, route.name ? [...parents, route.name] : parents, map);
        }
        if (!route.name && route.path) {
            throw new Error(`Route ${route.path} has no name`);
        }
        if (!route.name) {
            return;
        }
        const existingRoute = map.get(route.name);
        if (process.env.NODE_ENV !== 'production' && existingRoute) {
            // eslint-disable-next-line no-console
            console.warn(`Duplicate definition for route ${route.name}:\n- ${existingRoute.path}\n- ${route.path}`);
        }
        map.set(route.name, Object.assign({}, route, { parents }, (route.path ? {
            regex: new RegExp(`^${route.path.replace(/\/:\w+\?/g, '/?([\\w_-]*)').replace(/:\w+/g, '([\\w_-]+)')}\\/?$`),
        } : {})));
    });
    return map;
};
export class BaseRoutingContext {
    constructor(routesMap, location) {
        this.match = (pathname) => Array.from(this.routesMap.values())
            .find(route => !!route.regex && route.regex.test(pathname)) || null;
        this.getPath = (name, params) => buildRoutePath(this.routesMap, name, params);
        this.getRawPath = (name) => buildRawPath(this.routesMap, name);
        this.getRoute = (name) => {
            const route = this.routesMap.get(name);
            if (!route) {
                throw new Error(`Undefined route "${name}"`);
            }
            return route;
        };
        this.routesMap = routesMap;
        this.location = location;
    }
}
export class RoutingContext extends BaseRoutingContext {
    constructor(routesMap, location, history) {
        super(routesMap, location);
        this.push = (name, params) => this.history
            .push(buildRoutePath(this.routesMap, name, params));
        this.replace = (name, params) => this.history
            .replace(buildRoutePath(this.routesMap, name, params));
        this.history = history;
    }
}
export function buildRoutingContext(routes, location, history) {
    const map = mapRoutes(routes);
    if (!history) {
        return new BaseRoutingContext(map, location);
    }
    return new RoutingContext(map, location, history);
}
/* eslint-enable import/export */

==> react-named-router-0.3.2.tgz: package/es6/utils.js <==
const buildRawPath = (map, name) => {
    const route = map.get(name);
    if (!route) {
        throw new Error(`Undefined route "${name}"`);
    }
    if (!route.path) {
        throw new Error(`Route "${name}" does not have a path`);
    }
    return route.path;
};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const buildRoutePath = (map, name, params = {}) => (buildRawPath(map, name)
    .replace(/:\w+\??/g, (match) => {
    const paramKey = match.replace(/[:?]/g, '');
    const paramValue = params[paramKey];
    if (!paramValue && !match.includes('?')) {
        throw new Error(`Missing value for required param "${paramKey}"`);
    }
    return paramValue || '';
})
    .replace(/\/$/, ''));
export const mapRoutes = (routes, parents = [], map = new Map()) => {
    routes.forEach((route) => {
        if (route.routes) {
            mapRoutes(route.routes, route.name ? [...parents, route.name] : parents, map);
        }
        if (!route.name && route.path) {
            throw new Error(`Route ${route.path} has no name`);
        }
        if (!route.name) {
            return;
        }
        const existingRoute = map.get(route.name);
        if (process.env.NODE_ENV !== 'production' && existingRoute) {
            // eslint-disable-next-line no-console
            console.warn(`Duplicate definition for route ${route.name}:\n- ${existingRoute.path}\n- ${route.path}`);
        }
        map.set(route.name, Object.assign({}, route, { parents }, (route.path ? {
            regex: new RegExp(`^${route.path.replace(/\/:\w+\?/g, '/?([\\w_-]*)').replace(/:\w+/g, '([\\w_-]+)')}\\/?$`),
        } : {})));
    });
    return map;
};
export class BaseRoutingContext {
    constructor(routesMap) {
        this.location = null;
        this.match = (pathname) => Array.from(this.routesMap.values())
            .find(route => !!route.regex && route.regex.test(pathname)) || null;
        this.getPath = (name, params) => buildRoutePath(this.routesMap, name, params);
        this.getRawPath = (name) => buildRawPath(this.routesMap, name);
        this.getRoute = (name) => {
            const route = this.routesMap.get(name);
            if (!route) {
                throw new Error(`Undefined route "${name}"`);
            }
            return route;
        };
        this.routesMap = routesMap;
    }
}
export class RoutingContext extends BaseRoutingContext {
    constructor(routesMap, history) {
        super(routesMap);
        this.push = (name, params) => this.history
            .push(buildRoutePath(this.routesMap, name, params));
        this.replace = (name, params) => this.history
            .replace(buildRoutePath(this.routesMap, name, params));
        this.history = history;
    }
}
export function buildRoutingContext(routes, location, history) {
    const map = mapRoutes(routes);
    const context = history ? new RoutingContext(map, history) : new BaseRoutingContext(map);
    if (location) {
        context.location = typeof location === 'string' ? {
            pathname: location,
            search: '',
            state: {},
            hash: '',
        } : location;
    }
    return context;
}
/* eslint-enable import/export */
